.. :changelog:

=========
 History
=========

0.8.0 (2017-06-27)
------------------
* add support for hybernate power state (thanks Chen Rotem Levy)
* ensure hostdb is not world readable when created (thanks bodo-riediger)

0.7.0 (2017-03-24)
------------------
* add support for -p flag to prompt for password and bypass hostdb
* nice errors to the user when auth fails

0.6.0 (2016-10-27)
------------------
* add support for stand-by power state (thanks Chen Rotem Levy)

0.5.0 (2016-10-20)
------------------
* python 2 fixes for python 3 issues (thanks Chen Rotem Levy)

0.4.0 (2016-10-10)
------------------
* python 3 fixes and testing (thanks Rixillo)

0.3.0 (2015-10-08)
------------------
* python 3 print fix (thanks Mike Nawrocki)
* add set_next_boot and change_boot_order_request (thanks John L. Villalovos)

0.1.0 (2015-08-09)
---------------------

* First release on PyPI.
